<%@ WebHandler Language="C#" Class="ImageFromFile" %>

using System;
using System.Web;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;

public class ImageFromFile : IHttpHandler
{
    public void ProcessRequest(HttpContext context)
    {
        string fileName = context.Request.QueryString["fileName"];
        int width = int.Parse(context.Request.QueryString["width"]);
        int height = int.Parse(context.Request.QueryString["height"]);
        string key = string.Format("{0}|{1}|{2}", fileName, width, height);

       
        context.Response.ContentType = "image/png";

        context.Response.WriteFile(GetImageFile(context, fileName, width, height));

        context.Response.End();
    }

    private string GetImageFile(HttpContext context, string fileName, int width, int height) {
        string rootDir = context.Server.MapPath("~/");

        string imagePath = Path.Combine(rootDir, "ImageCache");

        if (!Directory.Exists(imagePath)) {
            Directory.CreateDirectory(imagePath);
        }

        string imageName = Path.Combine(imagePath, String.Format("{0}x{1}-{2}.png", width, height, Path.GetFileNameWithoutExtension(fileName)));

        if (!File.Exists(imageName)) {
            Color c = Color.FromArgb(0xff, 1, 1);
            using (Bitmap bmp = new Bitmap(width, height, PixelFormat.Format24bppRgb))
            {
                using (Graphics g = Graphics.FromImage(bmp))
                {                 
                    using (Image img = Bitmap.FromFile(fileName))
                    {
                        g.Clear(c);         
                        g.DrawImage(img, ImageRectangleFromFrame(img.Size, bmp.Size));
                    }
                }

                bmp.MakeTransparent(c);
                bmp.Save(imageName, ImageFormat.Png);            
            }
        }
        return imageName;        
    }

    public bool IsReusable
    {
        get
        {
            return true;
        }
    }

    public static Rectangle ImageRectangleFromFrame(Size image, Size frame)
    {
        float scaleX = (float)frame.Width / image.Width;
        float scaleY = (float)frame.Height / image.Height;
        float scaleMin = 1.0f;
        if ((scaleX < 1.0f) || (scaleY < 1.0f))
        {
            scaleMin = Math.Min(scaleX, scaleY);
        }
        int width = (int)Math.Round(image.Width * scaleMin);
        int height = (int)Math.Round(image.Height * scaleMin);
        int left = (frame.Width - width) / 2;
        int top = (frame.Height - height) / 2;
        return new Rectangle(left, top, width, height);
    }
}
